@@ -325,7 +325,7 @@ sub goToPortal {
 sub fetchId {
     my $t = Lemonldap::NG::Handler::Main::Headers->lmHeaderIn( $apacheRequest,
         'Cookie' );
-    my $vhost = $apacheRequest->hostname;
+    my $vhost             = $apacheRequest->hostname;
     my $lookForHttpCookie = $tsv->{securedCookie} =~ /^(2|3)$/
       && !(
         defined( $tsv->{https}->{$vhost} )
@@ -372,7 +372,8 @@ sub retrieveSession {
         $datas = $apacheSession->data;
 
         # Update the session to notify activity, if necessary
-        if ( $tsv->{timeoutActivity} ) {
+        if ( $tsv->{timeoutActivity} and ( time() - $datas->{_lastSeen} < 60 ) )
+        {
             $apacheSession->update( { '_lastSeen' => time } );
 
             if ( $apacheSession->error ) {
@@ -450,7 +451,7 @@ sub run ($$) {
         my $str = $1;
         Lemonldap::NG::Handler::Main::Logger->lmLog( 'CDA request', 'debug' );
         $apacheRequest->args($args);
-        my $redirectUrl = $class->_buildUrl( $apacheRequest->uri );
+        my $redirectUrl   = $class->_buildUrl( $apacheRequest->uri );
         my $redirectHttps = ( $redirectUrl =~ m/^https/ );
         Lemonldap::NG::Handler::Main::Headers->lmSetErrHeaderOut(
             $apacheRequest,
